@@ -38,22 +38,21 @@ def altitudeAggregation(calcFile, dem, outline, stat, bin_z=None):
     demGlacier = np.multiply(dem, outline)
     demGlacierArray = demGlacier[~np.isnan(demGlacier)]
     demGlacier_findMin = demGlacier[demGlacier != 0]
+    if bin_z == None or str(bin_z).isnumeric() == True:
+        z_bin_range = range(int(demGlacier_findMin.min()), int(demGlacier_findMin.max() + bin_z), bin_z)
+    else:
+        z_bin_range = bin_z
 
     calcFileArray = np.multiply(calcFile, outline)
     calcFileArray = calcFileArray[~np.isnan(calcFileArray)]
 
     # bin from dem raster, but operate on massBalance raster
     # returns: stats array for each bin, the bin edges, and the indices of each value in the bin edges
-    demBinCount = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='count',
-                        bins=range(int(demGlacier_findMin.min()), int(demGlacier_findMin.max() + bin_z), bin_z))
-    demBin_std = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='std',
-                        bins=range(int(demGlacier_findMin.min()), int(demGlacier_findMin.max() + bin_z), bin_z))
-    demBin_min = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='min',
-                        bins=range(int(demGlacier_findMin.min()), int(demGlacier_findMin.max() + bin_z), bin_z))
-    demBin_max = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='max',
-                        bins=range(int(demGlacier_findMin.min()), int(demGlacier_findMin.max() + bin_z), bin_z))
-    demBinStat = stats.binned_statistic(demGlacierArray, calcFileArray, statistic=stat,
-                        bins=range(int(demGlacier_findMin.min()), int(demGlacier_findMin.max() + bin_z), bin_z))
+    demBinCount = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='count', bins=z_bin_range)
+    demBin_std = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='std', bins=z_bin_range)
+    demBin_min = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='min', bins=z_bin_range)
+    demBin_max = stats.binned_statistic(demGlacierArray, calcFileArray, statistic='max', bins=z_bin_range)
+    demBinStat = stats.binned_statistic(demGlacierArray, calcFileArray, statistic=stat, bins=z_bin_range)
     binStat = demBinStat[0]
     binBoundaries = demBinStat[1]
     binCount = demBinCount[0]
